The :class:`MemorySimIndex` Class
---------------------------------

.. automodule:: pysimsearch.sim_index.memory_sim_index

.. autoclass:: pysimsearch.sim_index.MemorySimIndex
   :members:
   :inherited-members:
